# Slackipy Core

`slackipycore` helps you invite users to your Slack team/channel using Python. `slackipycore` is meant for advanced users and is written for [`slackipy`](https://github.com/avinassh/slackipy).

## Need A Web Version?

Check my project [`slackipy`](https://github.com/avinassh/slackipy).


## Requirements

`slackipycore` is Python 3 only library.

## API Reference

## Exceptions

## License

The mighty MIT license. Please check `LICENSE` for more details.